@@ -1,9 +1,12 @@
 #include "header.h"
 
+
+
+
 // binned spatial lorelogram:
 void Binned_Lorelogram(double *bins, double *data, int *lbins, double *moms,int *nbins)
 {
-  int h=0, i=0, j=0, n=0, p=0;
+  int h=0, i=0, j=0, n=0;
   double step=0.0,*n11,*n10,*n01,*n00;
 
   n11=(double *) calloc(*nbins-1, sizeof(double));
@@ -20,16 +23,15 @@ void Binned_Lorelogram(double *bins, double *data, int *lbins, double *moms,int
   //Computes the binned statistics:
   for(i=0;i<(*ncoord-1);i++)
     for(j=(i+1);j<*ncoord;j++){
-      if(lags[p]<=*maxdist){
+      if(mlags[i][j]<=*maxdist){
 	for(h=0;h<(*nbins-1);h++)
-	  if((bins[h]<=lags[p]) && (lags[p]<bins[h+1])){
+	  if((bins[h]<=mlags[i][j]) && (mlags[i][j]<bins[h+1])){
 	    for(n=0;n<*nrep;n++){
 	      if(data[n+i * *nrep] && data[n+j * *nrep]) n11[h]++;
 	      if(data[n+i * *nrep] && !data[n+j * *nrep]) n10[h]++;
 	      if(!data[n+i * *nrep] && data[n+j * *nrep]) n01[h]++;
 	      if(!data[n+i * *nrep] && !data[n+j * *nrep]) n00[h]++;
-	      }}}
-      p++;}
+	      }}}}
 // computing log odds ration in each bin
  for(h=0;h<(*nbins-1);h++){
    if(n11[h]&&n10[h]&&n01[h]&&n00[h]){
@@ -40,6 +42,22 @@ void Binned_Lorelogram(double *bins, double *data, int *lbins, double *moms,int
      lbins[h]=0;}}
   return;
 }
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 // binned spatial-temporal variogram:
 void Binned_Lorelogram_st(double *bins, double *bint, double *data, int *lbins, int *lbinst,
 			 int *lbint, double *moms,double *momst, double *momt, int *nbins, int *nbint)
@@ -96,7 +114,7 @@ void Binned_Lorelogram_st(double *bins, double *bint, double *data, int *lbins,
 		      if(data[(t+i * *ntime)+n* *nrep]&&!data[(t+j * *ntime)+n* *nrep]) n10s[h]++;
 		      if(!data[(t+i * *ntime)+n* *nrep]&&data[(t+j * *ntime)+n* *nrep]) n01s[h]++;
 		      if(!data[(t+i * *ntime)+n* *nrep]&&!data[(t+j * *ntime)+n* *nrep]) n00s[h]++;}}}}}
-	    if(v>t){// computes the spatial-temporal lorelogram:
+	    else{// computes the spatial-temporal lorelogram:
 	      if(mlags[i][j]<=*maxdist && mlagt[t][v]<=*maxtime){
 		q=0;
 		for(h=0;h<(*nbins-1);h++){
@@ -126,10 +144,20 @@ void Binned_Lorelogram_st(double *bins, double *bint, double *data, int *lbins,
      else momst[q]=log((n11[q]*n00[q])/(n01[q]*n10[q]));}
   return;
 }
+
+
+
+
+
+
+
+
+
+
 // binned spatial variogram:
 void Binned_Variogram(double *bins, double *data, int *lbins, double *moms, int *nbins)
 {
-  int h=0, i=0, j=0, n=0, p=0;
+  int h=0, i=0, j=0, n=0;
   double step=0.0;
   //Set the binnes step:
   step=(*maxdist-*minimdista)/(*nbins-1);
@@ -139,16 +167,43 @@ void Binned_Variogram(double *bins, double *data, int *lbins, double *moms, int
     bins[h]=bins[h-1]+step;
   //Computes the binned moments:
   for(i=0;i<(*ncoord-1);i++)
+    for(j=(i+1);j<*ncoord;j++){
+      if(mlags[i][j]<=*maxdist){
+	for(h=0;h<(*nbins-1);h++)
+	  if((bins[h]<=mlags[i][j]) && (mlags[i][j]<bins[h+1])){
+	    for(n=0;n<*nrep;n++){
+	      moms[h]+=0.5*pow(data[n+i * *nrep]-data[n+j * *nrep],2);
+	      lbins[h]+=1;}}}}
+  return;
+}
+
+// binned spatial variogram:
+void Binned_Variogram_2(double *bins, double *data, int *lbins, double *moms, int *nbins)
+{
+  int h=0, i=0, j=0, n=0,p=0;
+  double step=0.0;
+  //Set the binnes step:
+  step=(*maxdist-*minimdista)/(*nbins-1);
+  bins[0]= *minimdista;
+  //define bins:
+  for(h=1;h<*nbins;h++)
+    bins[h]=bins[h-1]+step;
+  //Computes the binned moments:
+  for(i=0;i<(*ncoord-1);i++){
     for(j=(i+1);j<*ncoord;j++){
       if(lags[p]<=*maxdist){
 	for(h=0;h<(*nbins-1);h++)
 	  if((bins[h]<=lags[p]) && (lags[p]<bins[h+1])){
 	    for(n=0;n<*nrep;n++){
 	      moms[h]+=0.5*pow(data[n+i * *nrep]-data[n+j * *nrep],2);
-	      lbins[h]+=1;}}}
-      p++;}
+	      lbins[h]+=1;}}
+	      p++;}}}
   return;
 }
+
+
+
+
 // binned spatial-temporal variogram:
 void Binned_Variogram_st(double *bins, double *bint, double *data, int *lbins, int *lbinst,
 			 int *lbint, double *moms,double *momst, double *momt, int *nbins, int *nbint)
@@ -186,7 +241,7 @@ int h=0, i=0, j=0, n=0;
 		    for(n=0;n<*nrep;n++){
 		      moms[h]+=0.5*pow(data[(t+i * *ntime)+n* *nrep]-data[(t+j * *ntime)+n* *nrep], 2);
 		      lbins[h]+=1;}}
-	    if(v>t){// computes the spatial-temporal variogram:
+	    else{// computes the spatial-temporal variogram:
 	      if(mlags[i][j]<=*maxdist && mlagt[t][v]<=*maxtime){
 		q=0;
 		for(h=0;h<(*nbins-1);h++)
@@ -198,101 +253,62 @@ int h=0, i=0, j=0, n=0;
 		    q++;}}}}}}
   return;
 }
-/*
-void Binned_Variogram_st(double *bins, double *bint, double *data, int *lbins,
-			 int *lbinst, int *lbint, double *moms, double *momst,
-			 double *momt, int *nbins, int *nbint)
+
+// binned spatial-temporal variogram:
+void Binned_Variogram_st2(double *bins, double *bint, double *data, int *lbins, int *lbinst,
+			 int *lbint, double *moms,double *momst, double *momt, int *nbins, int *nbint)
 {
-  int h=0, i=0, j=0, n=0, ndata=*ncoord * *ntime;
+int h=0, i=0, j=0, n=0, p=0;
   int q=0, t=0, u=0, v=0;
   double step=0.0;
   //defines the spatial bins:
-  step=(*maxdist-*minimdista)/(*nbins-1);
-  bins[0]= *minimdista;
+  step=*maxdist/(*nbins-1);
+  bins[0]=0;
   for(h=1;h<*nbins;h++)
     bins[h]=bins[h-1]+step;
   //defines the temporal bins:
-  bint[0]=*minimtime;
+  bint[0]=0;
   for(h=1;h<*nbint;h++)
-    bint[h]=bint[h-1]+bint[0];
-  //loops for the cross sptial-temporal differences
-  for(t=0;t<*ntime;t++) // first temporal component
-    {
-      for(v=t;v<*ntime;v++) // second temporal component
-	{
-	  for(i=0;i<*ncoord;i++) // first spatial component
-	    {
-	      for(j=0;j<*ncoord;j++) // second spatial component
-		{
-		  // START marginal spatial variogram
-		  if(t==v && j>i)
-		    {
-		      if(mlags[i][j]<=*maxdist)
-			  {
-			    for(h=0;h<(*nbins-1);h++)
-			      if((bins[h]<=mlags[i][j]) && (mlags[i][j]<bins[h+1]))
-				{
-				  for(n=0;n<*nrep;n++)
-				    {
-				      moms[h]+=0.5*pow(data[(t+i * *ntime)+n* *nrep]-
-						       data[(t+j * *ntime)+n* *nrep], 2);
-				      lbins[h]+=1;
-				    }
-				}
-			  }
-		    }
-		  // END marginal spatial variogram
-                  // START marginal temporal variogram
-		  if(v>t && i==j)
-		    {
-		      if(mlagt[t][v]<=*maxtime)
-			{
-			  for(u=0;u<*nbint;u++)
-			    if(bint[u]==mlagt[t][v])
-			      {
-				for(n=0;n<*nrep;n++)
-				  {
-				    momt[u]+=0.5*pow(data[(t+i * *ntime)+n* *nrep]-
-						     data[(v+i * *ntime)+n* *nrep], 2);
-				    lbint[u]+=1;
-				  }
-			      }
-			}
-		    }
-		  // END marignal temporal variogram
-		  // START cross spatial-temporal variogram
-		  if(v>t && j!=i)
-		    {
-		      if(mlags[i][j]<=*maxdist && mlagt[t][v]<=*maxtime)
-			{
-			  q=0;
-			  for(h=0;h<(*nbins-1);h++)
-			    for(u=0;u<*nbint;u++)
-			      {
-				if((bins[h]<=mlags[i][j]) && (mlags[i][j]<bins[h+1]) && (bint[u]==mlagt[t][v]))
-				  {
-				    for(n=0;n<*nrep;n++)
-				      {
-					momst[q]+=0.5*pow(data[(t+i * *ntime)+n* *nrep]-
-							  data[(v+j * *ntime)+n* *nrep], 2);
-					lbinst[q]+=1;
-				      }
-				  }
-				q++;
-			      }
-			}
-		    }
-		  // END cross spatial-temporal variogram
-		}
-	    }
-	}
-    }
+    bint[h]=bint[h-1]+minimtime[0];
+  //computes the empirical variogram:
+  for(i=0;i<*ncoord;i++)
+    for(t=0;t<*ntime;t++)
+      for(j=i;j<*ncoord;j++){
+	if(i==j)//computes the marignal temporal variogram:
+	  for(v=(t+1);v<*ntime;v++){
+	    if(lagt[p]<=*maxtime){
+	      for(u=0;u<*nbint;u++){
+		if(bint[u]==lagt[p]){
+		  for(n=0;n<*nrep;n++){
+		    momt[u]+=0.5*pow(data[(t+i * *ntime)+n* *nrep]-data[(v+i * *ntime)+n* *nrep], 2);
+		    lbint[u]+=1;}}}p++;}}
+	else{
+	  for(v=0;v<*ntime;v++){
+	    if(t==v){// computes the marginal spatial variogram:
+	      if(lags[p]<=*maxdist){
+		for(h=0;h<(*nbins-1);h++){
+		  if((bins[h]<=lags[p]) && (lags[p]<bins[h+1])){
+		    for(n=0;n<*nrep;n++){
+		      moms[h]+=0.5*pow(data[(t+i * *ntime)+n* *nrep]-data[(t+j * *ntime)+n* *nrep], 2);
+		      lbins[h]+=1;}}}p++;}}
+	    else{// computes the spatial-temporal variogram:
+	      if(lags[p]<=*maxdist && lagt[p]<=*maxtime){
+		q=0;
+		for(h=0;h<(*nbins-1);h++){
+		  for(u=0;u<*nbint;u++){
+		    if((bins[h]<=lags[p]) && (lags[p]<bins[h+1]) && (bint[u]==lagt[p])){
+		      for(n=0;n<*nrep;n++){
+			momst[q]+=0.5*pow(data[(t+i * *ntime)+n* *nrep]-data[(v+j * *ntime)+n* *nrep], 2);
+			lbinst[q]+=1;}}
+		    q++;}}
+		    p++;}}}}}
   return;
-  }*/
-// binned madogram:
+}
+
+// binned spatial madogram:
 void Binned_Madogram(double *bins, double *data, int *lbins, double *moms, int *nbins)
 {
-  int h=0, i=0, j=0, n=0, p=0;
+  int h=0, i=0, j=0, n=0;
   double step=0.0;
   //Set the binnes step:
   step=(*maxdist-*minimdista)/(*nbins-1);
@@ -303,23 +319,79 @@ void Binned_Madogram(double *bins, double *data, int *lbins, double *moms, int *
   //Computes the binned moments:
   for(i=0;i<(*ncoord-1);i++)
     for(j=(i+1);j<*ncoord;j++){
-      if(lags[p]<=*maxdist){
+      if(mlags[i][j]<=*maxdist){
 	for(h=0;h<(*nbins-1);h++)
-	  if((bins[h]<=lags[p]) && (lags[p]<bins[h+1])){
+	  if((bins[h]<=mlags[i][j]) && (mlags[i][j]<bins[h+1])){
 	    for(n=0; n<*nrep;n++){
 	      moms[h]+=0.5*fabs(data[n+i * *nrep]-data[n+j * *nrep]);
 	      lbins[h]+=1;}}}
-      p++;}
+     }
   return;
 }
+
+
+
+
+
+
+// binned spatial-temporal variogram:
+void Binned_Madogram_st(double *bins, double *bint, double *data, int *lbins, int *lbinst,
+			 int *lbint, double *moms,double *momst, double *momt, int *nbins, int *nbint)
+{
+int h=0, i=0, j=0, n=0;
+  int q=0, t=0, u=0, v=0;
+  double step=0.0;
+  //defines the spatial bins:
+  step=*maxdist/(*nbins-1);
+  bins[0]=0;
+  for(h=1;h<*nbins;h++)
+    bins[h]=bins[h-1]+step;
+  //defines the temporal bins:
+  bint[0]=0;
+  for(h=1;h<*nbint;h++)
+    bint[h]=bint[h-1]+minimtime[0];
+  //computes the empirical variogram:
+  for(i=0;i<*ncoord;i++)
+    for(t=0;t<*ntime;t++)
+      for(j=i;j<*ncoord;j++){
+	if(i==j){//computes the marignal temporal variogram:
+	  for(v=(t+1);v<*ntime;v++){
+	    if(mlagt[t][v]<=*maxtime)
+	      for(u=0;u<*nbint;u++)
+		if(bint[u]==mlagt[t][v])
+		  for(n=0;n<*nrep;n++){
+		    momt[u]+=0.5*fabs(data[(t+i * *ntime)+n* *nrep]-data[(v+i * *ntime)+n* *nrep]);
+		    lbint[u]+=1;}}}
+	else{
+	  for(v=0;v<*ntime;v++){
+	    if(t==v){// computes the marginal spatial variogram:
+	      if(mlags[i][j]<=*maxdist)
+		for(h=0;h<(*nbins-1);h++)
+		  if((bins[h]<=mlags[i][j]) && (mlags[i][j]<bins[h+1]))
+		    for(n=0;n<*nrep;n++){
+		      moms[h]+=0.5*fabs(data[(t+i * *ntime)+n* *nrep]-data[(t+j * *ntime)+n* *nrep]);
+		      lbins[h]+=1;}}
+	    else{// computes the spatial-temporal variogram:
+	      if(mlags[i][j]<=*maxdist && mlagt[t][v]<=*maxtime){
+		q=0;
+		for(h=0;h<(*nbins-1);h++)
+		  for(u=0;u<*nbint;u++){
+		    if((bins[h]<=mlags[i][j]) && (mlags[i][j]<bins[h+1]) && (bint[u]==mlagt[t][v]))
+		      for(n=0;n<*nrep;n++){
+			momst[q]+=0.5*fabs(data[(t+i * *ntime)+n* *nrep]-data[(v+j * *ntime)+n* *nrep]);
+			lbinst[q]+=1;}
+		    q++;}}}}}}
+  return;
+}
+
 // variogram cloud:
 void Cloud_Variogram(double *bins, double *data, int *lbins, double *moms, int *nbins)
 {
-  int h=0, i=0, j=0, n=0;
+  int  h=0,i=0, j=0, n=0;
  //Computes the cloud moments:
   for(i=0;i<(*ncoord-1);i++)
     for(j=(i+1);j<*ncoord;j++){
-      bins[h]=lags[h];
+      bins[h]=mlags[i][j];
       for(n=0;n<*nrep;n++)
 	moms[h]+=0.5*pow(data[n+i * *nrep]-data[n+j * *nrep],2);
       lbins[h]=*nrep;
@@ -333,32 +405,13 @@ void Cloud_Madogram(double *bins, double *data, int *lbins, double *moms, int *n
  //Computes the cloud momemts:
   for(i=0;i<(*ncoord-1);i++)
     for(j=(i+1);j<*ncoord;j++){
-      bins[h]=lags[h];
+       bins[h]=mlags[i][j];
       for(n=0;n<*nrep;n++)
 	moms[h]+=0.5*fabs(data[n+i * *nrep]-data[n+j * *nrep]);
       lbins[h]=*nrep;
       h++;}
   return;
 }
-// Least square method for Gaussian model:
-/*void LeastSquare_G(double *bins, double *bint, int *cormod, double *lbins, double *moms,
-		   int *nbins, int *nbint, double *nuis, double *par, double *res)
-{
-  int h=0;
-  double vario=0.0, varhat=0.0;
-  //Checks the nuisance parameters (nugget, sill and corr):
-  if(nuis[1]<0 || nuis[2]<=0 || CheckCor(cormod,1,0,par)==-2) {
-    *res=LOW; return;}
-  // Computes the least squares:
-  for(h=0;h<(*nbins-1);h++)
-    if(lbins[h]){
-      vario=moms[h]/lbins[h];// Computes the empirical variogram
-	//variogram=nugget+sill*(1-corr)
-      varhat=Variogram(cormod,0.5*(bins[h]+bins[h+1]),0,nuis,par);
-      if(varhat)
-	*res=*res-pow(vario-varhat,2)*lbins[h];}// Computes the least squares
-  return;
-  }*/
 // Least square method for Gaussian spatial-temporal random field:
 void LeastSquare_G(double *bins, double *bint, int *cormod, double *lbins, double *moms,
 		      int *nbins, int *nbint, double *nuis, double *par, double *res)
@@ -370,129 +423,111 @@ void LeastSquare_G(double *bins, double *bint, int *cormod, double *lbins, doubl
     *res=LOW; return;}
   // Computes the least squares:
   for(u=0;u<*nbint;u++)
-    for(h=0;h<*nbins;h++){
+    for(h=0;h<(*nbins-1);h++){
       vario=moms[i]/lbins[i];// Computes the empirical variogram
       varhat=Variogram(cormod,0.5*(bins[h]+bins[h+1]),bint[u],nuis,par);
-      *res=*res-pow(vario-varhat,2)*lbins[i];// Computes the least squares
+      *res=*res-pow(varhat-vario,2);// Computes the least squares
       i++;}
   return;
 }
-// Weighted least square method for Gaussian spatial random field:
-/*void WLeastSquare_G(double *bins, double *bint, int *cormod, double *lbins, double *moms,
-		    int *nbins, int *nbint, double *nuis, double *par, double *res)
-{
-  int h=0;
-  double vario=0.0, varhat=0.0;
-  //Checks the nuisance parameters (nugget, sill and corr):
-  if(nuis[1]<0 || nuis[2]<=0 || CheckCor(cormod,1,0,par)==-2) {
-    *res=LOW; return;}
-  // Computes the least squares:
-  for(h=0;h<(*nbins-1);h++)
-    if(lbins[h]){
-      vario=moms[h]/lbins[h];// Computes the empirical variogram
-	//variogram=nugget+sill*(1-corr)
-      varhat=Variogram(cormod,0.5*(bins[h]+bins[h+1]),0,nuis,par);
-      if(varhat)
-	*res=*res-pow(vario/varhat-1,2)*lbins[h];}// Computes the weighted least squares
-  return;
-  }*/
 // Weighted least square method for Gaussian spatial-temporal random field:
 void WLeastSquare_G(double *bins, double *bint, int *cormod, double *lbins, double *moms,
 		       int *nbins, int *nbint, double *nuis, double *par, double *res)
 {
-  int h=0, i=0, u=0;
-  double vario=0.0, varhat=0.0;
+  int h=0,i=0,u=0;
+  double vario=0.0,varhat=0.0;
   //Checks the nuisance parameters (nugget, sill and corr):
   if(nuis[1]<0 || nuis[2]<=0 || CheckCor(cormod,par)==-2) {
     *res=LOW; return;}
   // Computes the least squares:
   for(u=0;u<*nbint;u++)
-    for(h=0;h<*nbins;h++){
+    for(h=0;h<(*nbins-1);h++){
       vario=moms[i]/lbins[i];// Computes the empirical variogram
       varhat=Variogram(cormod,0.5*(bins[h]+bins[h+1]),bint[u],nuis,par);
-      *res=*res-pow(vario/varhat-1,2)*lbins[i];// Computes the weighted least squares
+      if(vario) *res=*res-pow(varhat-vario,2)*(lbins[i]/pow(vario,2));// Computes the weighted least squares
       i++;}
   return;
 }
-// Least square method for max-stable extremal-Gaussian model:
+// Least square method for max-stable extremal-Gaussian spatio-temporal random field:
 void LeastSquare_MEG(double *bins, double *bint, int *cormod, double *lbins, double *moms,
 		     int *nbins, int *nbint, double *nuis, double *par, double *res)
 {
-  int h=0;
-  double vario=0.0, extcoeff=0.0, extcfhat=0.0;
+  int h=0,i=0,u=0;
+  double vario=0.0,extcoeff=0.0,extcfhat=0.0;
   //Checks the nuisance and correlation parameters (sill, corr):
   if(nuis[0]<=0 || nuis[0]>1 || CheckCor(cormod,par)==-2) {
     *res=LOW; return;}
   // Computes the least squares:
-  for(h=0;h<(*nbins-1);h++)
-    if(lbins[h]){
-      vario=moms[h]/lbins[h];// Computes the variogram
+  for(u=0;u<*nbint;u++)
+    for(h=0;h<(*nbins-1);h++){
+      vario=moms[i]/lbins[i];// Computes the madogram
       extcoeff=(1+2*vario)/(1-2*vario);// Computes the extremal coefficient
       // Computes the extremal coefficient for the Gaussian extremal model:
-      extcfhat=1+sqrt(0.5*(1-nuis[0]*CorFct(cormod,0.5*(bins[h]+bins[h+1]),0,par)));
-      *res=*res-pow(extcoeff-extcfhat,2);}// Computes the least squares
+      extcfhat=1+sqrt(0.5*(1-nuis[0]*CorFct(cormod,0.5*(bins[h]+bins[h+1]),bint[u],par)));
+      *res=*res-pow(extcoeff-extcfhat,2);// Computes the least squares
+      i++;}
   return;
 }
-
-// Weighted least square method for max-stable extremal-Gaussian model:
+// Weighted least square method for max-stable extremal-Gaussian spatio-temporal random field:
 void WLeastSquare_MEG(double *bins, double *bint, int *cormod, double *lbins, double *moms,
 		      int *nbins, int *nbint, double *nuis, double *par, double *res)
 {
-  int h=0;
-  double variogram=0.0, vario=0.0;
-
-  for(h=0;h<(*nbins-1);h++)
-    if(lbins[h])
-      {
-	variogram=moms[h]/lbins[h];
-	vario=nuis[0]+nuis[1]*//nugget+sill*(1-corr)
-	  (1-CorFct(cormod, (bins[h]+bins[h + 1])/2,0,par));
-	if(vario)
-	  *res=*res-pow(variogram/vario-1, 2)*lbins[h];
-      }
+  int h=0,i=0,u=0;
+  double extcfhat=0.0,extcoeff=0.0,vario=0.0;
+  //Checks the nuisance and correlation parameters (sill, corr):
+  if(nuis[0]<=0 || nuis[0]>1 || CheckCor(cormod,par)==-2) {
+    *res=LOW; return;}
+ // Computes the least squares:
+  for(u=0;u<*nbint;u++)
+    for(h=0;h<(*nbins-1);h++){
+      vario=moms[i]/lbins[i];// Computes the madogram
+      extcoeff=(1+2*vario)/(1-2*vario);// Computes the extremal coefficient
+      // Computes the extremal coefficient for the Gaussian extremal model:
+      extcfhat=1+sqrt(0.5*(1-nuis[0]*CorFct(cormod,0.5*(bins[h]+bins[h+1]),bint[u],par)));
+      *res=*res-pow(extcoeff/extcfhat-1,2)*lbins[h];
+      i++;}
   return;
 }
-
-// Least square method for max-stable Brown-Resnick model:
+// Least square method for max-stable Brown-Resnick spatio-temporal random field:
 void LeastSquare_MBR(double *bins, double *bint, int *cormod, double *lbins, double *moms,
 		     int *nbins, int *nbint, double *nuis, double *par, double *res)
 {
-  int h=0;
-  double vario=0.0, extcoeff=0.0, extcfhat=0.0;
+  int h=0,i=0,u=0;
+  double vario=0.0,extcoeff=0.0,extcfhat=0.0;
   //Checks the nuisance and correlation parameters (sill, corr):
-  if(VarioFct(cormod,1,par)==-2) {
+  if(nuis[0]<=0 || nuis[0]>1 || CheckCor(cormod,par)==-2) {
     *res=LOW; return;}
   // Computes the least squares:
-  for(h = 0; h < (*nbins - 1); h++)
-    if(lbins[h]){
-      vario=moms[h]/lbins[h];// Computes the variogram
+  for(u=0;u<*nbint;u++)
+    for(h=0;h<(*nbins-1);h++){
+      vario=moms[i]/lbins[i];// Computes the madogram
       extcoeff=(1+2*vario)/(1-2*vario);// Computes the extremal coefficient
-      // Computes the extremal coefficient for the Brown-Renick model:
-      extcfhat=2*pnorm(0.5*sqrt(VarioFct(cormod,0.5*(bins[h]+bins[h+1]),par)),0,1,1,0);
-      *res=*res-pow(extcoeff-extcfhat,2);}// Computes the least squares
+      // Computes the extremal coefficient for the Gaussian extremal model:
+      extcfhat=2*pnorm(0.5*sqrt(VarioFct(cormod,0.5*(bins[h]+bins[h+1]),par,bint[u])),0,1,1,0);
+      *res=*res-pow(extcoeff-extcfhat,2);// Computes the least squares
+      i++;}
   return;
 }
-
-// Least square method for max-stable extremal-t model:
+// Least square method for max-stable extremal-t spatio-temporal random field:
 void LeastSquare_MET(double *bins, double *bint, int *cormod, double *lbins, double *moms,
 		     int *nbins, int *nbint, double *nuis, double *par, double *res)
 {
-  int h=0;
-  double df1=0.0, rho=0.0, vario=0.0, extcoeff=0.0, extcfhat=0.0;
-  //Checks the nuisance and correlation parameters (df, sill, corr):
+  int h=0,i=0,u=0;
+  double df1=0.0,rho=0.0,vario=0.0,extcoeff=0.0,extcfhat=0.0;
+  //Checks the nuisance and correlation parameters (sill, corr):
   if(nuis[0]<=0 || nuis[1]<=0 || nuis[1]>1 || CheckCor(cormod,par)==-2) {
     *res=LOW; return;}
-  df1=nuis[0]+1;// Set the df of the t cdf:
+  df1=nuis[0]+1;// Set the df of the t cdf
   // Computes the least squares:
-  for(h=0;h<(*nbins-1);h++)
-    if(lbins[h]){
-      vario=moms[h]/lbins[h];// Computes the variogram
+  for(u=0;u<*nbint;u++)
+    for(h=0;h<(*nbins-1);h++){
+      vario=moms[i]/lbins[i];// Computes the madogram
       extcoeff=(1+2*vario)/(1-2*vario);// Computes the extremal coefficient
-      rho=nuis[1]*CorFct(cormod,0.5*(bins[h]+bins[h+1]),0,par);
-      // Computes the extremal coefficient for the extremal-t model:
+      rho=nuis[1]*CorFct(cormod,0.5*(bins[h]+bins[h+1]),bint[u],par);
+      // Computes the extremal coefficient for the extremal-t model model:
       extcfhat=2*pt(sqrt(df1*(1-rho)/(1+rho)),df1,1,0);
-      *res=*res-pow(extcoeff-extcfhat,2);}// Computes the least squares
+      *res=*res-pow(extcoeff-extcfhat,2);// Computes the least squares
+      i++;}
   return;
 }
 
-
